OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Katselin",
    "Error loading {name}" : "Virhe ladatessa {name}",
    "Your browser does not support the video tag." : "Käyttämäsi selain ei tue video-tagia.",
    "Open sidebar" : "Avaa sivupalkki",
    "View" : "Näytä",
    "Share" : "Jaa"
},
"nplurals=2; plural=(n != 1);");
